@@ -1,11 +1,10 @@
 """
-Module models.htc
------------------
+.. _models-htc:
 
-Created on 2021.07.30
-:author: Felix Soubelet (felix.soubelet@cern.ch)
+HTCondor Models
+---------------
 
-A module with `pydantic` models to validate and store data obtained by querying the HTCondor queue.
+Module with ``pydantic`` models to validate and store data obtained by querying the ``HTCondor`` queue.
 """
 from typing import Union
 
@@ -14,6 +13,12 @@ from pydantic import BaseModel
 
 
 class BaseSummary(BaseModel):
+    """
+    .. versionadded:: 0.12.0
+
+    Class to encompass and validate the cluster's summary line in the ``condor_q`` output.
+    """
+
     jobs: int
     completed: int
     removed: int
@@ -24,6 +29,12 @@ class BaseSummary(BaseModel):
 
 
 class ClusterSummary(BaseModel):
+    """
+    .. versionadded:: 0.12.0
+
+    Class to encompass and validate the cluster's info line in the ``condor_q`` output.
+    """
+
     scheduler_id: str
     query: BaseSummary
     user: BaseSummary
@@ -31,6 +42,12 @@ class ClusterSummary(BaseModel):
 
 
 class HTCTaskSummary(BaseModel):
+    """
+    .. versionadded:: 0.12.0
+
+    Class to encompass and validate a specific job's line in the ``condor_q`` output.
+    """
+
     owner: str
     batch_name: int
     submitted: DateTime
