@@ -1,11 +1,10 @@
 """
-Module plotting.helpers
------------------------
+.. _plotting-helpers:
 
-Created on 2019.06.15
-:author: Felix Soubelet (felix.soubelet@cern.ch)
+Plotting Helpers
+----------------
 
-A collection of functions for more descriptive plots.
+A collection of utility functions for more descriptive plots.
 """
 from typing import Tuple
 
@@ -14,8 +13,9 @@ import matplotlib.axes
 
 class AnnotationsPlotter:
     """
-    A class to encapsulate all useful plotting additional tidbits.
-    """
+    .. versionadded:: 0.6.0
+
+    A class to encapsulate all useful plotting additional tidbits."""
 
     @staticmethod
     def set_arrow_label(
@@ -29,22 +29,35 @@ class AnnotationsPlotter:
         **kwargs,
     ) -> matplotlib.text.Annotation:
         """
-        Add a label box with text and an arrow from the box to a specified position to an existing
-        provided matplotlib.axes `Axes` instance. Original code from Guido Sterbini.
+        Adds on the provided `matplotlib.axes.Axes` a label box with text and an arrow from the box to a specified position.
+        Original code from :user:`Guido Sterbini <sterbini>`.
 
         Args:
-            axis (matplotlib.axes.Axes): a matplotlib axis to plot on.
+            axis (matplotlib.axes.Axes): a `matplotlib.axes.Axes` to plot on.
             label (str): label text to print on the axis.
             arrow_position (Tuple[float, float]): where on the plot to point the tip of the arrow.
             label_position (Tuple[float, float]): where on the plot the text label (and thus start
                 of the arrow) is.
-            color (str): color parameter for your arrow and label. Defaults to 'k'.
+            color (str): color parameter for your arrow and label. Defaults to "k".
             arrow_arc_rad (float): angle value defining the upwards / downwards shape of and
                 bending of the arrow.
-            fontsize (int): text size in the box
+            fontsize (int): text size in the box.
 
         Returns:
-            A matploblit text annotation object.
+            A `matploblit.text.Annotation` of the created annotation.
+
+        Example:
+            .. code-block:: python
+
+                >>> AnnotationsPlotter.set_arrow_label(
+                ...     axis=ax,
+                ...     label="Your label",
+                ...     arrow_position=(1, 2),
+                ...     label_position=(1.1 * some_value, 0.75 * another_value),
+                ...     color="indianred",
+                ...     arrow_arc_rad=0.3,
+                ...     fontsize=25,
+                ... )
         """
         return axis.annotate(
             label,
@@ -58,7 +71,7 @@ class AnnotationsPlotter:
             ha="center",
             bbox=dict(boxstyle="round4", fc="w", color=color, lw=2),
             arrowprops=dict(
-                arrowstyle="-|>", connectionstyle="arc3,rad=" + str(arrow_arc_rad), fc="w", color=color, lw=2,
+                arrowstyle="-|>", connectionstyle="arc3,rad=" + str(arrow_arc_rad), fc="w", color=color, lw=2
             ),
             **kwargs,
         )
