@@ -1,11 +1,14 @@
 """
-Module utils.printutil
-----------------------
+.. _utils-printutils:
 
-Created on 2019.12.11
-:author: Felix Soubelet (felix.soubelet@cern.ch)
+Printing Utilities
+------------------
 
 A class utility class to allow me printing text in color, bold, etc.
+
+.. warning::
+   This module's functionality is superseeded by the ``rich`` package, and it will be 
+   removed in a future release.
 """
 
 END = "\033[0m"
@@ -13,6 +16,8 @@ END = "\033[0m"
 
 class Background:
     """
+    .. versionadded:: 0.2.0
+
     ANSI color escape sequences for the background of a terminal output.
     """
 
@@ -28,6 +33,8 @@ class Background:
 
 class Foreground:
     """
+    .. versionadded:: 0.2.0
+
     ANSI color escape sequences for the foreground of a terminal output.
     """
 
@@ -50,6 +57,8 @@ class Foreground:
 
 class Styles:
     """
+    .. versionadded:: 0.2.0
+
     ANSI style escape sequences for a terminal output.
     """
 
